package com.ruoyi.rocketmq.mapper;

import com.ruoyi.rocketmq.domain.RmDeploymentPolicy;

import java.util.List;

/**
 * 服务器脚本策略Mapper接口
 * 
 * @author gyt
 * @date 2025-09-15
 */
public interface RmDeploymentPolicyMapper 
{
    /**
     * 查询服务器脚本策略
     * 
     * @param id 服务器脚本策略主键
     * @return 服务器脚本策略
     */
    public RmDeploymentPolicy selectRmDeploymentPolicyById(Long id);

    /**
     * 查询服务器脚本策略列表
     * 
     * @param rmDeploymentPolicy 服务器脚本策略
     * @return 服务器脚本策略集合
     */
    public List<RmDeploymentPolicy> selectRmDeploymentPolicyList(RmDeploymentPolicy rmDeploymentPolicy);

    /**
     * 新增服务器脚本策略
     * 
     * @param rmDeploymentPolicy 服务器脚本策略
     * @return 结果
     */
    public int insertRmDeploymentPolicy(RmDeploymentPolicy rmDeploymentPolicy);

    /**
     * 修改服务器脚本策略
     * 
     * @param rmDeploymentPolicy 服务器脚本策略
     * @return 结果
     */
    public int updateRmDeploymentPolicy(RmDeploymentPolicy rmDeploymentPolicy);

    /**
     * 删除服务器脚本策略
     * 
     * @param id 服务器脚本策略主键
     * @return 结果
     */
    public int deleteRmDeploymentPolicyById(Long id);

    /**
     * 批量删除服务器脚本策略
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRmDeploymentPolicyByIds(Long[] ids);

    /**
     * 根据clientId查询未下发的服务器脚本策略
     * @param queryParam
     * @return
     */
    List<RmDeploymentPolicy> selectRmDeploymentPolicyByClientId(RmDeploymentPolicy queryParam);
}
